@@ -1,20 +1,20 @@
-from pm4pymdl.objects.mdl.importer import factory as mdl_importer
+from pm4pymdl.objects.mdl.importer import importer as mdl_importer
 from pm4pymdl.algo.mvp.utils import succint_mdl_to_exploded_mdl, exploded_mdl_to_succint_mdl
 from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
-from pm4pymdl.algo.mvp.gen_framework import factory as mdfg_disc_factory
-from pm4pymdl.algo.mvp.gen_framework2 import factory as mdfg_disc_factory2
+from pm4pymdl.algo.mvp.gen_framework import algorithm as mdfg_disc_factory
+from pm4pymdl.algo.mvp.gen_framework2 import algorithm as mdfg_disc_factory2
 from pm4pymdl.algo.mvp.gen_framework3 import discovery as mdfg_disc_factory3
-from pm4pymdl.algo.mvp.get_logs_and_replay import factory as petri_disc_factory
-from pm4pymdl.visualization.mvp.gen_framework import factory as mdfg_vis_factory
-from pm4pymdl.visualization.mvp.gen_framework2 import factory as mdfg_vis_factory2
-from pm4pymdl.visualization.mvp.gen_framework3 import factory as mdfg_vis_factory3
-from pm4pymdl.visualization.petrinet import factory as pn_vis_factory
+from pm4pymdl.algo.mvp.get_logs_and_replay import algorithm as petri_disc_factory
+from pm4pymdl.visualization.mvp.gen_framework import visualizer as mdfg_vis_factory
+from pm4pymdl.visualization.mvp.gen_framework2 import visualizer as mdfg_vis_factory2
+from pm4pymdl.visualization.mvp.gen_framework3 import visualizer as mdfg_vis_factory3
+from pm4pymdl.visualization.petrinet import visualizer as pn_vis_factory
 from pm4pymdl.algo.mvp.utils import get_activ_attrs_with_type, get_activ_otypes
 from pm4pymdl.algo.mvp.utils import filter_act_attr_val, filter_act_ot, filter_timestamp, filter_metaclass, \
     filter_specific_path
 from pm4pymdl.algo.mvp.utils import distr_act_attrname, distr_act_otype, dist_timestamp, clean_objtypes
-from pm4pymdl.algo.mvp.discovery import factory as mvp_discovery
-from pm4pymdl.visualization.mvp import factory as mvp_vis_factory
+from pm4pymdl.algo.mvp.discovery import algorithm as mvp_discovery
+from pm4pymdl.visualization.mvp import visualizer as mvp_vis_factory
 from controllers import defaults
 import numpy as np
 import pandas as pd
@@ -28,8 +28,8 @@ from networkx.algorithms.community import quality
 from scipy.linalg.blas import sgemm
 from scipy import spatial
 from pm4py.objects.log.log import EventStream
-from pm4py.objects.conversion.log import factory as log_conv_factory
-from pm4py.objects.log.exporter.xes import factory as xes_exporter
+from pm4py.objects.conversion.log import converter as log_conv_factory
+from pm4py.objects.log.exporter.xes import exporter as xes_exporter
 from pm4py.objects.log.util import sorting
 from collections import Counter
 
