@@ -1,6 +1,6 @@
-from pm4pymdl import algo, objects, visualization, order_log_generation
+from pm4pymdl import algo, objects, visualization, order_log_generation, util
 
-__version__ = '0.0.25'
+__version__ = '0.0.26'
 __doc__ = "Process Mining for Python - Multi-Dimensional Event Logs"
 __author__ = 'PADS'
 __author_email__ = 'a.berti@pads.rwth-aachen.de'
