@@ -1,9 +1,9 @@
 import pandas as pd
 from pm4pymdl.algo.mvp.gen_framework2 import general
 from pm4pymdl.algo.mvp.utils import clean_frequency, clean_arc_frequency
-from pm4py.objects.conversion.log import factory as log_conv_factory
+from pm4py.objects.conversion.log import converter as log_conv_factory
 from pm4py.objects.log.log import EventStream
-from pm4py.algo.discovery.inductive import factory as inductive_miner
+from pm4py.algo.discovery.inductive import algorithm as inductive_miner
 from collections import Counter
 from pm4py.objects.log.util import sorting
 
